#
# spec file for package perl-Devel-NYTProf
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-Devel-NYTProf
Version:        6.05
Release:        bp153.1.14
%define cpan_name Devel-NYTProf
Summary:        Powerful fast feature-rich Perl source code profiler
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/Devel-NYTProf/
Source0:        https://cpan.metacpan.org/authors/id/T/TI/TIMB/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(File::Which) >= 1.09
BuildRequires:  perl(JSON::MaybeXS)
BuildRequires:  perl(Test::Differences) >= 0.60
BuildRequires:  perl(Test::More) >= 0.84
Requires:       perl(File::Which) >= 1.09
Requires:       perl(JSON::MaybeXS)
Requires:       perl(Test::Differences) >= 0.60
Requires:       perl(Test::More) >= 0.84
%{perl_requires}

%description
Devel::NYTProf is a powerful, fast, feature-rich perl source code profiler.

  * Performs per-line statement profiling for fine detail

  * Performs per-subroutine statement profiling for overview

  * Performs per-opcode profiling for slow perl builtins

  * Performs per-block statement profiling (the first profiler to do so)

  * Accounts correctly for time spent after calls return

  * Performs inclusive and exclusive timing of subroutines

  * Subroutine times are per calling location (a powerful feature)

  * Can profile compile-time activity, just run-time, or just END time

  * Uses novel techniques for efficient profiling

  * Sub-microsecond (100ns) resolution on supported systems

  * Very fast - the fastest statement and subroutine profilers for perl

  * Handles applications that fork, with no performance cost

  * Immune from noise caused by profiling overheads and I/O

  * Program being profiled can stop/start the profiler

  * Generates richly annotated and cross-linked html reports

  * Captures source code, including string evals, for stable results

  * Trivial to use with mod_perl - add one line to httpd.conf

  * Includes an extensive test suite

  * Tested on very large codebases

NYTProf is effectively two profilers in one: a statement profiler, and a
subroutine profiler.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes HACKING README.md

%changelog
* Tue Mar 27 2018 coolo@suse.com
- updated to 6.05
  see /usr/share/doc/packages/perl-Devel-NYTProf/Changes
  =head2 Changes in Devel::NYTProf 6.05 - 23rd March 2018
    Fix test failures on Perl 5.27.6+ #113
    Fix to prevent memory corruption in incr_sub_inclusive_time
    thanks to lucrocha #115
    Fix test failures on Perl 5.26 w/ PERL_USE_UNSAFE_INC=0,
    thanks to Kent Fredric #112
    Fix for the double opening of the web browser with --open,
    thanks to trizen #107
    Updated links in docs from old svn repository to Github
    thanks to smpeters #114
* Fri Nov 25 2016 coolo@suse.com
- updated to 6.04
  see /usr/share/doc/packages/perl-Devel-NYTProf/Changes
  =head2 Changes in Devel::NYTProf 6.04 - 24th November 2016
    Fixed build on perl 5.25+ due to OpSIBLING, thanks to Dan Collins #102
    Fixed nytprofmerge on Windows thanks to andrey-starodubtsev #99
    Fixed nytprofhtml invalid UTF-8 char and improved CSS #105
    Fixed spelling mistake in nytprofcsv docs. Closes #95
    Table headers now stay visible, thanks to Sebastian Rose #106
    Assorted improvments to .travis.yml
* Mon Apr  4 2016 coolo@suse.com
- updated to 6.03
  see /usr/share/doc/packages/perl-Devel-NYTProf/Changes
  =head2 Changes in Devel::NYTProf 6.03 - 25th March 2016
    Fix to account for the deep stack optimizations in perl 5.23.8
    by Dave Mitchell, with my great gratitude!
    Fix SIGUSR2 on MSWin32 and div by zero #78 PR#79
    with thanks to Nicolas Georges.
    Fix for perl 5.8.8 but adding definition for tTHX.
    Unify 'Profile format error' messages.
    Improve the TROUBLESHOOTING docs.
    Added some more docs for the start=init option #85
    Corrected URL of KCachegrind home page #87
    with thanks to Denis Ibaev.
    Corrected URL of sample report #80
    Removed dead code.nytimes.com URL and redundant history #84
* Wed Aug  5 2015 coolo@suse.com
- updated to 6.02
  see /usr/share/doc/packages/perl-Devel-NYTProf/Changes
  =head2 Changes in Devel::NYTProf 6.02 - 2nd August 2015
    FlameGraphs upgraded the latest version, which supports searching.
    Use JSON::MaybeXS instead of JSON::Any (deprecated), thanks to Ether #73
    Updated metacpan urls, thanks to Ether #74
    Internal context optimizations, thanks to jandubois #75
* Thu Apr 16 2015 coolo@suse.com
- updated to 6.01
  see /usr/share/doc/packages/perl-Devel-NYTProf/Changes
* Fri Oct  4 2013 coolo@suse.com
- updated to 5.06
  Fixed for perl 5.19.4. RT#88288 thanks to sprout.
  Fixed test for change in perl 5.18.x error message text.
  Fixed to no longer open a file when start=no. RT#86497/RT#87404.
  Fixed compiler warnings. RT#86728 thanks to Alexander Bluhm.
  Document that Devel::NYTProf needs to be loaded as early as possible
    even when using start=no. PR#10 thanks to moritz.
  Removed unused keyword $Id$. PR#9 thanks to dsteinbrunner.
  Removed old benchmark.pl files. RT#86704.
  Corrected assorted typos. PR#8 thanks to dsteinbrunner.
  Added meta-spec to META_MERGE. PR#12 thanks to dsteinbrunner.
* Wed Jul 24 2013 coolo@suse.com
- updated to 5.05
  Fixed crash on "Can't use string as a subroutine ref" error,
    and probably other die-at-pp_entersub cases,
    with thanks to Zefram. RT#86638
  Fixed crash with libcexit=1, thanks to Zefram. RT#86548
  Allow negative times in tests for systems with unstable clocks
    thanks to Gisle Aas, RT#85556.
  Added libcexit=1 option thanks to Zefram, RT#75912.
  Added documentation for endatexit and libcexit options.
  Added documentation for nytprofhtml --minimal
    thanks to Mike Doherty, RT#86039.
* Tue Jun  4 2013 coolo@suse.com
- updated to 5.03
  Fix windows to use flamegraph.bat [Christian Walde]
  Generates META.yml which mentions github repo [Christian Walde]
  Add meta robots noindex to html pages [Tokuhiro Matsuno]
  Can't rely on #!-line to always work, PR#3
    thanks to Gisle Aas.
  Avoid triggering "gcc internal compiler error" PR#4
    thanks to Gisle Aas.
  Added subroutine entry and return event stream,
    controlled via the calls=N option. Default calls=1.
  Added nytprofcalls command to process the call event stream to
    generate timings for distinct call stacks (experimental).
  Added Flame Graph visualization SVG using the call stack data.
  Changed blocks=N option to be 0 (disabled) by default.
  Fixed test for perl 5.17+ hash randomization.
  Fixed nytprofhtml for Windows thanks to Jan Dubois. PR#2
  Fixed assorted nits thanks to Steve Peters. PR#1
  Deprecated nytprofcsv - speak up if you use it!
  No longer warn about $&, $` and $' being slow if $] >= 5.017008.
  Fix u2time clock (ie Time::HiRes, used by Windows)
  Clarify sigexit option docs.
  Loosen test timing constraints (for slow cpantester VMs).
  Significant improvement in the accuracy of the subroutine profiler,
    especially for frequent calls to very short duration subs/ops,
    and more so for POSIX and OSX systems with sub-microsecond clocks.
  Fixed tests to work with perl 5.17.7+ (PL_sawampersand gone).
  Fixed some doc typos thanks to Jesse Sheidlower.
  Improved nytprofmerge behaviour with inconsistent attributes.
  Removed the usecputime=1 option. Use clock=N instead if possible.
  Moved main repo to git (and https://github.com/timbunce/devel-nytprof)
* Wed Sep 21 2011 jreidinger@suse.com
- fix non-executables in bin
* Fri Jan 14 2011 coolo@novell.com
- initial package 4.06
  * created by cpanspec 1.78.03
